@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-our $VERSION = '2.20180726'; # VERSION
+our $VERSION = '2.20180903'; # VERSION
 
 
 use Digest::MD5 qw{ md5_hex };
@@ -90,6 +90,43 @@ sub metric_send {
 }
 
 
+sub rbl_check_ip {
+    my ( $self, $ip, $list ) = @_;
+
+    my $lookup_ip;
+
+    # Reverse the IP
+    if ( $ip->version() == 4 ) {
+        $lookup_ip = join( '.', reverse( split( /\./, $ip->ip() ) ) );
+    }
+    elsif ( $ip->version() == 6 ) {
+        my $ip_string = $ip->ip();
+        $ip_string =~ s/://g;
+        $lookup_ip = join( '.', reverse( split( '', $ip_string ) ) );
+    }
+
+    return 0 if ! $lookup_ip;
+    return $self->rbl_check_domain( $lookup_ip, $list );
+}
+
+
+sub rbl_check_domain {
+    my ( $self, $domain, $list ) = @_;
+    my $resolver = $self->get_object( 'resolver' );
+    my $lookup = join( '.', $domain, $list );
+    my $packet = $resolver->query( $lookup, 'A' );
+
+    if ($packet) {
+        foreach my $rr ( $packet->answer ) {
+            if (  lc $rr->type eq 'a' ) {
+                return 1;
+            }
+        }
+    }
+    return 0;
+}
+
+
 sub get_microseconds {
     my ( $self ) = @_;
     my ($seconds, $microseconds) = gettimeofday;
@@ -1977,7 +2014,7 @@ Mail::Milter::Authentication::Handler
 
 =head1 VERSION
 
-version 2.20180726
+version 2.20180903
 
 =head1 DESCRIPTION
 
@@ -2183,6 +2220,20 @@ Send metrics to the parent
 
 Return details of the metrics this module exports.
 
+=head1 RBL METHODS
+
+=head2 I<rbl_check_ip( $ip, $list )>
+
+Check the given IP address against an rbl list.
+
+Returns true is listed.
+
+=head2 I<rbl_check_domain( $domain, $list )>
+
+Check the given domain against an rbl list.
+
+Returns true is listed.
+
 =head1 TIMEOUT METHODS
 
 =head2 I<get_microseconds()>
