@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180726'; # VERSION
+our $VERSION = '2.20180903'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -29,6 +29,7 @@ sub default_config {
         'no_report'      => 0,
         'config_file'    => '/etc/mail-dmarc.ini',
         'no_reject_disposition' => 'quarantine',
+        'no_list_reject_disposition' => 'none',
     };
 }
 
@@ -47,7 +48,43 @@ sub is_whitelisted {
     my $ip_obj = $top_handler->{'ip_object'};
     my $whitelisted = 0;
     foreach my $entry ( @{ $config->{'whitelisted'} } ) {
-        if ( $entry =~ /^dkim:/ ) {
+        # This does not consider dkim/spf results added by a passing arc chain
+        # we consider this out of scope at this point.
+        if ( $entry =~ /^dnswl:/ ) {
+            my ( $dummy, $type, $rbl ) = split( /:/, $entry, 3 );
+            if ( $type eq 'spf' ) {
+                eval {
+                    my $spf = $self->get_handler('SPF');
+                    if ( $spf ) {
+                        my $got_spf_result = $spf->{'dmarc_result'};
+                        if ( $got_spf_result eq 'pass' ) {
+                            my $got_spf_domain = $spf->{'dmarc_domain'};
+                            if ( $self->rbl_check_domain( $got_spf_domain, $rbl ) ) {
+                                $self->dbgout( 'DMARCReject', "Whitelist hit " . $entry, LOG_INFO );
+                                $whitelisted = 1;
+                            }
+                        }
+                    }
+                };
+                $self->handle_exception( $@ );
+            }
+            elsif ( $type eq 'dkim' ) {
+                my $dkim_handler = $self->get_handler('DKIM');
+                foreach my $dkim_domain( sort keys %{ $dkim_handler->{'valid_domains'}} ) {
+                    if ( $self->rbl_check_domain( $dkim_domain, $rbl ) ) {
+                        $self->dbgout( 'DMARCReject', "Whitelist hit " . $entry, LOG_INFO );
+                        $whitelisted = 1;
+                    }
+                }
+            }
+            elsif ( $type eq 'ip' ) {
+                if ( $self->rbl_check_ip( $ip_obj, $rbl ) ) {
+                    $self->dbgout( 'DMARCReject', "Whitelist hit " . $entry, LOG_INFO );
+                    $whitelisted = 1;
+                }
+            }
+        }
+        elsif ( $entry =~ /^dkim:/ ) {
             my ( $dummy, $dkim_domain ) = split( /:/, $entry, 2 );
             my $dkim_handler = $self->get_handler('DKIM');
             if ( exists( $dkim_handler->{'valid_domains'}->{ lc $dkim_domain } ) ) {
@@ -55,6 +92,23 @@ sub is_whitelisted {
                 $whitelisted = 1;
             }
         }
+        elsif ( $entry =~ /^spf:/ ) {
+            my ( $dummy, $spf_domain ) = split( /:/, $entry, 2 );
+            eval {
+                my $spf = $self->get_handler('SPF');
+                if ( $spf ) {
+                    my $got_spf_result = $spf->{'dmarc_result'};
+                    if ( $got_spf_result eq 'pass' ) {
+                        my $got_spf_domain = $spf->{'dmarc_domain'};
+                        if ( lc $got_spf_domain eq lc $spf_domain ) {
+                            $self->dbgout( 'DMARCReject', "Whitelist hit " . $entry, LOG_INFO );
+                            $whitelisted = 1;
+                        }
+                    }
+                }
+            };
+            $self->handle_exception( $@ );
+        }
         else {
             my $whitelisted_obj = Net::IP->new($entry);
             my $is_overlap = $ip_obj->overlaps($whitelisted_obj) || 0;
@@ -69,6 +123,7 @@ sub is_whitelisted {
                 $whitelisted = 1;
             }
         }
+        return $whitelisted if $whitelisted;
     }
     return $whitelisted;
 }
@@ -368,6 +423,8 @@ sub _process_dmarc_for {
         $arc_aware_result = $arc_result->result;
     }
 
+    my $is_whitelisted = $self->is_whitelisted();
+
     # Reject mail and/or set policy override reasons
     if ( $dmarc_code eq 'fail' ) {
         # Policy override decisions.
@@ -377,20 +434,21 @@ sub _process_dmarc_for {
             $dmarc_disposition = 'none';
             $dmarc_result->reason( 'type' => 'trusted_forwarder', 'comment' => 'Policy overriden using trusted ARC chain' );
         }
-        elsif ( $config->{'no_list_reject'} && $self->{'is_list'} ) {
-            $self->dbgout( 'DMARCReject', "Policy reject overridden for list mail", LOG_INFO );
-            $policy_override = 'mailing_list';
-            $dmarc_result->reason( 'type' => $policy_override, 'comment' => 'Policy ignored due to local mailing list policy' );
-            $dmarc_result->disposition('none');
-            $dmarc_disposition = 'none';
-        }
-        elsif ( $self->is_whitelisted() ) {
+        elsif ( $is_whitelisted ) {
             $self->dbgout( 'DMARCReject', "Policy reject overridden by whitelist", LOG_INFO );
             $policy_override = 'trusted_forwarder';
             $dmarc_result->reason( 'type' => $policy_override, 'comment' => 'Policy ignored due to local white list' );
             $dmarc_result->disposition('none');
             $dmarc_disposition = 'none';
         }
+        elsif ( $config->{'no_list_reject'} && $self->{'is_list'} ) {
+            $self->dbgout( 'DMARCReject', "Policy reject overridden for list mail", LOG_INFO );
+            $policy_override = 'mailing_list';
+            $dmarc_result->reason( 'type' => $policy_override, 'comment' => 'Policy ignored due to local mailing list policy' );
+            my $no_list_reject_disposition = $config->{ 'no_list_reject_disposition' } // 'none';
+            $dmarc_result->disposition( $no_list_reject_disposition );
+            $dmarc_disposition = $no_list_reject_disposition;
+        }
 
         if ( $dmarc_disposition eq 'reject' ) {
             if ( $config->{'hard_reject'} ) {
@@ -460,7 +518,7 @@ sub _process_dmarc_for {
         'disposition'      => $dmarc_disposition,
         'policy'           => $dmarc_policy,
         'is_list'          => ( $self->{'is_list'}      ? '1' : '0' ),
-        'is_whitelisted'   => ( $self->is_whitelisted() ? '1' : '0'),
+        'is_whitelisted'   => ( $is_whitelisted ? '1' : '0'),
         'arc_aware_result' => $arc_aware_result,
         'used_arc'         => ( $arc_aware_result ? '1' : '0' ),
     };
@@ -802,7 +860,7 @@ Mail::Milter::Authentication::Handler::DMARC
 
 =head1 VERSION
 
-version 2.20180726
+version 2.20180903
 
 =head1 DESCRIPTION
 
@@ -817,6 +875,7 @@ This handler requires the SPF and DKIM handlers to be installed and active.
             "hard_reject"           : 0,                   | Reject mail which fails with a reject policy
             "no_reject_disposition" : "quarantine",        | What to report when hard_reject is 0
             "no_list_reject"        : 0,                   | Do not reject mail detected as mailing list
+            "no_list_reject_disposition" : "none",         | Disposition to use for mail detected as mailing list (defaults none)
             "whitelisted"           : [                    | A list of ip addresses or CIDR ranges, or dkim domains
                 "10.20.30.40",                             | for which we do not want to hard reject mail on fail p=reject
                 "dkim:bad.forwarder.com",                  | (valid) DKIM signing domains can also be whitelisted by
