@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Protocol::SMTP;
 use strict;
 use warnings;
-our $VERSION = '2.20180726'; # VERSION
+our $VERSION = '2.20180903'; # VERSION
 
 use English qw{ -no_match_vars };
 use Email::Date::Format qw{ email_date };
@@ -610,7 +610,7 @@ sub smtp_command_data {
     }
 
     $self->smtp_status('smtp.i.body');
-    my $body_chunk;
+    my $body_chunk = q{};
     if ( ! $done ) {
         eval {
             alarm( $smtp->{'smtp_timeout_in'} );
@@ -1076,7 +1076,7 @@ Mail::Milter::Authentication::Protocol::SMTP
 
 =head1 VERSION
 
-version 2.20180726
+version 2.20180903
 
 =head1 SYNOPSIS
 
